# parcellate

[![Release](https://img.shields.io/github/v/release/GalKepler/parcellate)](https://img.shields.io/github/v/release/GalKepler/parcellate)
[![Build status](https://img.shields.io/github/actions/workflow/status/GalKepler/parcellate/main.yml?branch=main)](https://github.com/GalKepler/parcellate/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/GalKepler/parcellate)](https://img.shields.io/github/commit-activity/m/GalKepler/parcellate)
[![License](https://img.shields.io/github/license/GalKepler/parcellate)](https://img.shields.io/github/license/GalKepler/parcellate)

A simple tool for extracting regional statistics from scalar neuroimaging maps.
